Wakati.Me
=========

Wakati.Me is a time tracking api for text editors. This is the command line
event appender for the Wakati.Me api. You shouldn't need to directly use
this outside of a text editor plugin.


Installation
------------

https://www.wakati.me/help/plugins/installing-plugins
